# eric7.Plugins.VcsPlugins.vcsPySvn.SvnPropListDialog

Module implementing a dialog to show the output of the svn proplist command process.

### Global Attributes

None

### Classes

SvnPropListDialog | Class implementing a dialog to show the output of the svn proplist command process.

### Functions

None

## SvnPropListDialog

Class implementing a dialog to show the output of the svn proplist command process.

### Derived from

QWidget, SvnDialogMixin, Ui_SvnPropListDialog

### Class Attributes

None

### Class Methods

None

### Methods

SvnPropListDialog | Constructor
__finish | Private slot called when the process finished or the user pressed the button.
__generateItem | Private method to generate a properties item in the properties list.
__resizeColumns | Private method to resize the list columns.
__resort | Private method to resort the tree.
__showError | Private slot to show an error message.
on_buttonBox_clicked | Private slot called by a button of the button box clicked.
on_refreshButton_clicked | Private slot to refresh the status display.
start | Public slot to start the svn status command.

### Static Methods

None

#### SvnPropListDialog (Constructor)

SvnPropListDialog(vcs, parent=None)

Constructor

vcs
  reference to the vcs object
parent
  parent widget (QWidget)

#### SvnPropListDialog.__finish

__finish()

Private slot called when the process finished or the user pressed the button.

#### SvnPropListDialog.__generateItem

__generateItem(path, propName, propValue)

Private method to generate a properties item in the properties list.

path
  file/directory name the property applies to (string)
propName
  name of the property (string)
propValue
  value of the property (string)

#### SvnPropListDialog.__resizeColumns

__resizeColumns()

Private method to resize the list columns.

#### SvnPropListDialog.__resort

__resort()

Private method to resort the tree.

#### SvnPropListDialog.__showError

__showError(msg)

Private slot to show an error message.

msg
  error message to show (string)

#### SvnPropListDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot called by a button of the button box clicked.

button
  button that was clicked (QAbstractButton)

#### SvnPropListDialog.on_refreshButton_clicked

on_refreshButton_clicked()

Private slot to refresh the status display.

#### SvnPropListDialog.start

start(fn, recursive=False)

Public slot to start the svn status command.

fn
  filename(s) (string or list of strings)
recursive
  flag indicating a recursive list is requested

Up